# tidevice3
[![PyPI version](https://badge.fury.io/py/tidevice3.svg)](https://badge.fury.io/py/tidevice3)
[![codecov](https://codecov.io/gh/codeskyblue/tidevice3/graph/badge.svg?token=twFRe9igek)](https://codecov.io/gh/codeskyblue/tidevice3)

wrapper for pymobiledevice3 to make it more easy to use.


# Install

```bash
pip install tidevice3

# or install as Isolated environment
brew install pipx
pipx install tidevice3
```

# Usage
```bash
$ t3 list
...

$ t3 developer
# enable developer mode and mount develoepr image

$ t3 --help
# show help
```

# LICENSE
[MIT](LICENSE)